@@ -49,12 +49,13 @@ from shippinglabel.requirements import ComparableRequirement, combine_requiremen
 
 # this package
 from pyproject_parser.classes import License, Readme, _NormalisedName
-from pyproject_parser.type_hints import Author, BuildSystemDict, ProjectDict
+from pyproject_parser.type_hints import Author, BuildSystemDict, DependencyGroupsDict, ProjectDict
 from pyproject_parser.utils import PyProjectDeprecationWarning, content_type_from_filename, render_readme
 
 __all__ = [
 		"RequiredKeysConfigParser",
 		"BuildSystemParser",
+		"DependencyGroupsParser",
 		"PEP621Parser",
 		]
 
@@ -155,6 +156,16 @@ class BuildSystemParser(RequiredKeysConfigParser):
 	factories: ClassVar[Dict[str, Callable[..., Any]]] = {"requires": list}
 	defaults: ClassVar[Dict[str, Any]] = {"build-backend": None, "backend-path": None}
 
+	@staticmethod
+	def normalize_requirement_name(name: str) -> str:
+		"""
+		Function to normalize a requirement name per e.g. :pep:`503` (where underscores are replaced by hyphens).
+
+		.. versionadded:: 0.9.0
+		"""
+
+		return normalize(name)
+
 	@_documentation_url("https://peps.python.org/pep-0518/")
 	def parse_requires(self, config: Dict[str, TOML_TYPES]) -> List[ComparableRequirement]:
 		"""
@@ -181,7 +192,7 @@ class BuildSystemParser(RequiredKeysConfigParser):
 
 			parsed_dependencies.add(requirement)
 
-		return sorted(combine_requirements(parsed_dependencies))
+		return sorted(combine_requirements(parsed_dependencies, normalize_func=self.normalize_requirement_name))
 
 	@_documentation_url("https://peps.python.org/pep-0517/")
 	def parse_build_backend(self, config: Dict[str, TOML_TYPES]) -> str:
@@ -248,6 +259,60 @@ class BuildSystemParser(RequiredKeysConfigParser):
 		return cast(BuildSystemDict, parsed_config)
 
 
+class DependencyGroupsParser(AbstractConfigParser):
+	"""
+	Parser for the :pep:`dependency groups table <735#specification>` table from ``pyproject.toml``.
+
+	.. versionadded:: 0.13.0
+	"""  # noqa: RST399
+
+	table_name: ClassVar[str] = "dependency-groups"
+
+	@property
+	def keys(self) -> List[str]:
+		"""
+		The keys to parse from the TOML file.
+		"""
+
+		return []
+
+	@staticmethod
+	def parse_group(config: TOML_TYPES) -> List[Union[str, Dict[str, str]]]:
+		"""
+		Parse a group from the TOML configuration.
+
+		:param config:
+		"""
+
+		if isinstance(config, list):
+			return config
+
+		raise BadConfigError("A dependency group must be an array.")
+
+	def parse(
+			self,
+			config: Dict[str, TOML_TYPES],
+			set_defaults: bool = False,
+			) -> DependencyGroupsDict:
+		"""
+		Parse the TOML configuration.
+
+		:param config:
+		:param set_defaults: If :py:obj:`True`, the values in
+			:attr:`self.defaults <dom_toml.parser.AbstractConfigParser.defaults>` and
+			:attr:`self.factories <dom_toml.parser.AbstractConfigParser.factories>`
+			will be set as defaults for the returned mapping.
+
+		:rtype:
+
+		.. latex:clearpage::
+		"""
+
+		parsed_config = {key: self.parse_group(value) for key, value in config.items()}
+
+		return cast(DependencyGroupsDict, parsed_config)
+
+
 class PEP621Parser(RequiredKeysConfigParser):
 	"""
 	Parser for :pep:`621` metadata from ``pyproject.toml``.
@@ -886,10 +951,6 @@ class PEP621Parser(RequiredKeysConfigParser):
 			nbval = "nbval.plugin"
 
 		:param config: The unparsed TOML config for the :pep621:`project table <table-name>`.
-
-		:rtype:
-
-		.. latex:clearpage::
 		"""
 
 		entry_points = config["entry-points"]
@@ -918,6 +979,16 @@ class PEP621Parser(RequiredKeysConfigParser):
 
 		return entry_points
 
+	@staticmethod
+	def normalize_requirement_name(name: str) -> str:
+		"""
+		Function to normalize a requirement name per e.g. :pep:`503` (where underscores are replaced by hyphens).
+
+		.. versionadded:: 0.9.0
+		"""
+
+		return normalize(name)
+
 	@_documentation_url("https://whey.readthedocs.io/en/latest/configuration.html#tconf-project.dependencies")
 	def parse_dependencies(self, config: Dict[str, TOML_TYPES]) -> List[ComparableRequirement]:
 		"""
@@ -962,7 +1033,10 @@ class PEP621Parser(RequiredKeysConfigParser):
 
 			parsed_dependencies.add(requirement)
 
-		return sorted(combine_requirements(parsed_dependencies))
+		return sorted(combine_requirements(
+				parsed_dependencies,
+				normalize_func=self.normalize_requirement_name,
+				))
 
 	@_documentation_url(
 			"https://whey.readthedocs.io/en/latest/configuration.html#tconf-project.optional-dependencies"
@@ -1068,7 +1142,13 @@ class PEP621Parser(RequiredKeysConfigParser):
 							f"expected {str!r}, got {type(dep)!r}"
 							)
 
-		return {e: sorted(combine_requirements(d)) for e, d in parsed_optional_dependencies.items()}
+		combined_requirements = {}
+		for extra, deps in parsed_optional_dependencies.items():
+			combined_requirements[extra] = sorted(
+					combine_requirements(deps, normalize_func=self.normalize_requirement_name)
+					)
+
+		return combined_requirements
 
 	def parse(  # type: ignore[override]
 		self,
